@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: downloader-view.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: downloader-view.c 7198 2007-07-26 04:14:07Z diegoe $
  */
 
 #include "config.h" 
@@ -173,7 +173,14 @@ downloader_view_class_init (DownloaderViewClass *klass)
 static void
 show_downloader_cb (DownloaderView *dv)
 {
-	gtk_window_present (GTK_WINDOW (dv->priv->window));
+	if (!gtk_window_has_toplevel_focus (GTK_WINDOW (dv->priv->window)))
+	{
+		gtk_window_present (GTK_WINDOW (dv->priv->window));
+	}
+	else
+	{
+		gtk_widget_hide (dv->priv->window);
+	}
 }
 
 static gboolean
@@ -205,7 +212,7 @@ show_status_icon (DownloaderView *dv)
 {
 	DownloaderViewPrivate *priv = dv->priv;
 
-	priv->status_icon = gtk_status_icon_new_from_stock (EPHY_STOCK_DOWNLOAD);
+	priv->status_icon = gtk_status_icon_new_from_stock (STOCK_DOWNLOAD);
 
 	g_signal_connect_swapped (priv->status_icon, "activate",
 				  G_CALLBACK (show_downloader_cb), dv);
@@ -705,7 +712,7 @@ downloader_view_build_ui (DownloaderView *dv)
 
 	priv->model = GTK_TREE_MODEL (liststore);
 
-	gtk_window_set_icon_name (GTK_WINDOW (priv->window), EPHY_STOCK_DOWNLOAD);
+	gtk_window_set_icon_name (GTK_WINDOW (priv->window), STOCK_DOWNLOAD);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
 	g_signal_connect (selection, "changed", G_CALLBACK (selection_changed), dv);
