@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: EphyHeaderSniffer.cpp,v 1.48 2006/09/13 11:34:14 chpe Exp $
+ * $Id: EphyHeaderSniffer.cpp 7166 2007-07-15 10:19:27Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -233,7 +233,7 @@ EphyHeaderSniffer::GetInterface(const nsIID & uuid, void * *result)
 			EphyBadCertRejector *badCertRejector = new EphyBadCertRejector ();
 			if (!badCertRejector) return NS_ERROR_OUT_OF_MEMORY;
 
-			*result = NS_STATIC_CAST(nsIBadCertListener*, badCertRejector);
+			*result = static_cast<nsIBadCertListener*>(badCertRejector);
 			NS_ADDREF (badCertRejector);
 
 			return NS_OK;
