@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphySingle.cpp 7035 2007-05-19 16:45:55Z chpe $
+ *  $Id: EphySingle.cpp 7158 2007-07-14 22:20:22Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -350,7 +350,7 @@ mozilla_cookie_to_ephy_cookie (nsICookie *cookie)
 
 #ifdef HAVE_GECKO_1_9
         PRBool isHttpOnly = PR_FALSE;
-        cookie2->GetHttpOnly (&isHttpOnly);
+        cookie2->GetIsHttpOnly (&isHttpOnly);
         info->is_http_only = isHttpOnly != PR_FALSE;
 #endif
 
