@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: mozilla-embed.cpp 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: mozilla-embed.cpp 7166 2007-07-15 10:19:27Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -975,7 +975,7 @@ mozilla_embed_emit_mouse_signal (MozillaEmbed *embed,
 	nsCOMPtr<nsIDOMEvent> dev = do_QueryInterface (ev);
 	NS_ENSURE_TRUE (dev, FALSE);
 
-	info = mozilla_embed_event_new (NS_STATIC_CAST (gpointer, dev));
+	info = mozilla_embed_event_new (static_cast<gpointer>(dev));
 
 	event_context.Init (mpriv->browser);
         rv = event_context.GetMouseEventInfo (ev, MOZILLA_EMBED_EVENT (info));
