@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-location-entry.c 7062 2007-05-31 19:43:10Z diegoe $
+ *  $Id: ephy-location-entry.c 7138 2007-07-10 13:14:52Z chpe $
  */
 
 #include "config.h"
@@ -53,7 +53,6 @@
 #include <gtk/gtkseparatormenuitem.h>
 #include <gtk/gtkalignment.h>
 #include <gtk/gtkclipboard.h>
-#include <gtk/gtkversion.h>
 
 #include <string.h>
 
@@ -61,7 +60,6 @@
 
 struct _EphyLocationEntryPrivate
 {
-	GtkTooltips *tips;
 	EphyIconEntry *icon_entry;
 	GtkWidget *icon_ebox;
 	GtkWidget *icon;
@@ -166,21 +164,6 @@ ephy_location_entry_get_type (void)
 	return type;
 }
 
-static gboolean
-ephy_location_entry_set_tooltip (GtkToolItem *tool_item,
-				 GtkTooltips *tooltips,
-				 const char *tip_text,
-				 const char *tip_private)
-{
-	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (tool_item);
-	EphyLocationEntryPrivate *priv = entry->priv;
-
-	gtk_tooltips_set_tip (tooltips, priv->icon_entry->entry,
-			      tip_text, tip_private);
-
-	return TRUE;
-}
-
 static void
 ephy_location_entry_style_set (GtkWidget *widget,
 			       GtkStyle *previous_style)
@@ -246,8 +229,6 @@ ephy_location_entry_finalize (GObject *object)
 		g_object_unref (priv->favicon);
 	}
 
-	g_object_unref (priv->tips);
-
 	parent_class->finalize (object);
 }
 
@@ -256,7 +237,6 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-	GtkToolItemClass *tool_item_class = GTK_TOOL_ITEM_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
 
@@ -264,8 +244,6 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 
 	widget_class->style_set = ephy_location_entry_style_set;
 
-	tool_item_class->set_tooltip = ephy_location_entry_set_tooltip;
-
 	signals[USER_CHANGED] = g_signal_new (
 		"user_changed", G_OBJECT_CLASS_TYPE (klass),
 		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
@@ -910,8 +888,8 @@ ephy_location_entry_construct_contents (EphyLocationEntry *entry)
 	g_signal_connect (priv->icon_ebox, "button-press-event",
 			  G_CALLBACK (icon_button_press_event_cb), entry);
 
-	gtk_tooltips_set_tip (priv->tips, priv->icon_ebox,
-			      _("Drag and drop this icon to create a link to this page"), NULL);
+	gtk_widget_set_tooltip_text (priv->icon_ebox,
+			             _("Drag and drop this icon to create a link to this page"));
 
 	priv->icon = gtk_image_new ();
 	gtk_container_add (GTK_CONTAINER (priv->icon_ebox), priv->icon);
@@ -969,9 +947,6 @@ ephy_location_entry_init (EphyLocationEntry *le)
 
 	p->user_changed = TRUE;
 
-	p->tips = gtk_tooltips_new ();
-	g_object_ref_sink (p->tips);
-
 	ephy_location_entry_construct_contents (le);
 
 	gtk_tool_item_set_expand (GTK_TOOL_ITEM (le), TRUE);
@@ -1000,7 +975,6 @@ sort_func (GtkTreeModel *model,
 	return valueb - valuea;
 }
 
-#if GTK_CHECK_VERSION (2, 11, 0)
 static gboolean
 cursor_on_match_cb  (GtkEntryCompletion *completion,
 		     GtkTreeModel *model,
@@ -1021,7 +995,6 @@ cursor_on_match_cb  (GtkEntryCompletion *completion,
 
 	return TRUE;
 }
-#endif /* GTK+ 2.11.0 */
 
 void
 ephy_location_entry_set_completion (EphyLocationEntry *le,
@@ -1093,11 +1066,9 @@ ephy_location_entry_set_completion (EphyLocationEntry *le,
 	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (completion),
 				       extracell, "text", extra_col);
 
-#if GTK_CHECK_VERSION (2, 11, 0)
 	g_object_set (completion, "inline-selection", TRUE, NULL);
 	g_signal_connect (completion, "cursor-on-match",
 			  G_CALLBACK (cursor_on_match_cb), le);
-#endif
 
 	gtk_entry_set_completion (GTK_ENTRY (priv->icon_entry->entry), completion);
 	g_object_unref (completion);
@@ -1304,5 +1275,5 @@ ephy_location_entry_set_lock_tooltip (EphyLocationEntry *entry,
 {
 	EphyLocationEntryPrivate *priv = entry->priv;
 
-	gtk_tooltips_set_tip (priv->tips, priv->lock_ebox, tooltip, NULL);
+	gtk_widget_set_tooltip_text (priv->lock_ebox, tooltip);
 }
