@@ -15,9 +15,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmarks.c 6783 2007-01-03 08:08:12Z diegoe $
+ *  $Id: ephy-bookmarks.c 7175 2007-07-16 20:22:51Z wbolster $
  */
 
 #include "config.h"
@@ -1074,7 +1074,7 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 	 * translated string. */
 	/* Translators: this is an automatic topic containing local
 	 * websites bookmarks autodiscovered with zeroconf. */
-	const char *bk_local_sites = Q_("bookmarks|Local Sites");
+	const char *bk_local_sites = Q_("bookmarks|Nearby Sites");
 #endif
 
 	eb->priv = EPHY_BOOKMARKS_GET_PRIVATE (eb);
@@ -1668,6 +1668,7 @@ ephy_bookmarks_get_topic_uri (EphyBookmarks *eb,
 #ifdef ENABLE_ZEROCONF
 	else if (ephy_bookmarks_get_local (eb) == node)
 	{
+		/* Note: do not change to "Nearby" because of existing custom toolbars */
 		uri = g_strdup ("topic://Special/Local");
 	}
 #endif
