@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2002-2004 Marco Pesenti Gritti <mpeseng@tin.it>
- *  Copyright (C) 2005, 2006 Peter Harvey <pah06@uow.edu.au>
+ *  Copyright © 2002-2004 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright © 2005, 2006 Peter Harvey <pah06@uow.edu.au>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
@@ -71,7 +71,7 @@ ephy_topics_entry_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyTopicsEntryClass),
 			NULL,
