@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-tab.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-tab.c 7197 2007-07-25 21:04:10Z diegoe $
  */
 
 #include "config.h"
@@ -1723,8 +1723,11 @@ update_net_state_message (EphyTab *tab, const char *uri, EphyEmbedNetState flags
 	else if (msg != NULL)
 	{
 		g_free (tab->priv->status_message);
+		g_free (tab->priv->loading_title);
 		tab->priv->status_message = g_strdup_printf (msg, host);
+		tab->priv->loading_title = g_strdup_printf (msg, host);
 		g_object_notify (G_OBJECT (tab), "message");
+		g_object_notify (G_OBJECT (tab), "title");
 	}
 
 out:
